const path = require('path')
const fs = require('fs')

/**
 * Sorts dependencies in package.json alphabetically.
 * They are unsorted because they were grouped for the handlebars helpers
 * @param {object} data Data from questionnaire
 */
function sortDependencies(data) {
  // Code from https://github.com/vuejs-templates/webpack/blob/develop/utils/index.js
  const packageJsonFile = path.join(data.inPlace ? '' : data.destDirName, 'package.json')
  const packageJson = JSON.parse(fs.readFileSync(packageJsonFile))
  packageJson.devDependencies = sortObject(packageJson.devDependencies)
  packageJson.dependencies = sortObject(packageJson.dependencies)
  fs.writeFileSync(packageJsonFile, JSON.stringify(packageJson, null, 2) + '\n')
}

function sortObject(object) {
  // Based on https://github.com/yarnpkg/yarn/blob/v1.3.2/src/config.js#L79-L85
  const sortedObject = {}
  Object.keys(object)
    .sort()
    .forEach(item => {
      sortedObject[item] = object[item]
    })
  return sortedObject
}

module.exports = {
  helpers: {},
  prompts: {
    name: {
      type: 'string',
      required: true,
      message: 'Project name',
    },
    description: {
      type: 'string',
      required: false,
      message: 'Project description',
      default: 'A Vue.js project',
    },
    author: {
      type: 'string',
      message: 'Author',
    },
    bp:{
      type: 'confirm',
      message: 'install partner modules in App?',
    },
    project:{
      type: 'confirm',
      message: 'install project modules in App?',
    },
    contract:{
      type: 'confirm',
      message: 'install contract modules in App?',
    },
    wfl:{
      type: 'confirm',
      message: 'install workflow modules in App?',
    },
    calculate:{
      type: 'confirm',
      message: 'install calculate modules in App?',
    },
    riskstrom:{
      type: 'confirm',
      message: 'install riskstrom modules in App?',
    },
    robot:{
      type: 'confirm',
      message: 'install robot modules in App?',
    },
    esign:{
      type: 'confirm',
      message: 'install esign modules in App?',
    },
    report:{
      type: 'confirm',
      message: 'install report modules in App?',
    },
    qixin:{
      type: 'confirm',
      message: 'install QiXinBao modules in App?',
    },
    ocr:{
      type: 'confirm',
      message: 'install ocr modules in App?',
    },
  },
  filters: {
    'src/pages/applications/partnerManager/**/*': 'bp',
    'scr/pages/applications/workflow/**/*' :'wfl',
    'src/pages/applications/financCalculate/**/*': 'calculate',
    'src/pages/applications/projectManager/**/*': 'project',
    'src/pages/applications/contractSign/**/*': 'contract',
    'src/pages/applications/contractMainten/**/*': 'contract',
    'src/pages/applications/riskStorm/**/*': 'riskstrom',
    'src/pages/applications/robot/**/*': 'robot',
    'src/pages/applications/esign/**/*': 'esign',
    'src/pages/applications/reports/**/*': 'report',
    'src/pages/applications/qiXinBao/**/*': 'qixin',
    'src/pages/applications/ocrIdentify/**/*': 'ocr'
  },
  complete(data, { chalk }) {
    sortDependencies(data)
  },
}
